@@ -14,10 +14,10 @@ test_that("pptx summary", {
   example_pptx <- system.file(package = "officer", "doc_examples/example.pptx")
   doc <- read_pptx(path = example_pptx)
   doc_data <- pptx_summary(doc)
-  table_data <- dplyr::filter(doc_data, content_type == "table cell", row_id == 1)
+  table_data <- dplyr::filter(doc_data, content_type == "table cell", row_id == 1, slide_id == 1)
   expect_equal( table_data$text, c("Header 1 ", "Header 2", "Header 3") )
 
-  table_data <- dplyr::filter(doc_data, content_type == "table cell", row_id == 4)
+  table_data <- dplyr::filter(doc_data, content_type == "table cell", row_id == 4, slide_id == 1)
   expect_equal( table_data$text, c("B", "9.0", "Salut") )
 })
 
